@@ -9,7 +9,7 @@
  * workings can be found in the book "Software Solutions in C" by
  * Dale Schumacher, Academic Press, ISBN: 0-12-632360-7.
  *
- * $Header: /cvsroot/pgsql/src/backend/utils/adt/cash.c,v 1.51.2.1 2002/02/19 22:19:42 tgl Exp $
+ * $Header: /cvsroot/pgsql/src/backend/utils/adt/cash.c,v 1.61 2003/09/25 06:58:03 petere Exp $
  */
 
 #include "postgres.h"
@@ -17,10 +17,9 @@
 #include <limits.h>
 #include <ctype.h>
 #include <math.h>
-#ifdef USE_LOCALE
 #include <locale.h>
-#endif
 
+#include "libpq/pqformat.h"
 #include "miscadmin.h"
 #include "utils/builtins.h"
 #include "utils/cash.h"
@@ -63,7 +62,7 @@ CashGetDatum(Cash value)
  * XXX HACK It looks as though some of the symbols for
  *	monetary values returned by localeconv() can be multiple
  *	bytes/characters. This code assumes one byte only. - tgl 97/04/14
- * XXX UNHACK Allow the currency symbol to be multi-byte.
+ * XXX UNHACK Allow the currency symbol to be multibyte.
  *	- thomas 1998-03-01
  */
 Datum
@@ -83,11 +82,7 @@ cash_in(PG_FUNCTION_ARGS)
 				psymbol,
 			   *nsymbol;
 
-#ifdef USE_LOCALE
 	struct lconv *lconvert = PGLC_localeconv();
-#endif
-
-#ifdef USE_LOCALE
 
 	/*
 	 * frac_digits will be CHAR_MAX in some locales, notably C.  However,
@@ -108,14 +103,6 @@ cash_in(PG_FUNCTION_ARGS)
 	csymbol = ((*lconvert->currency_symbol != '\0') ? lconvert->currency_symbol : "$");
 	psymbol = ((*lconvert->positive_sign != '\0') ? *lconvert->positive_sign : '+');
 	nsymbol = ((*lconvert->negative_sign != '\0') ? lconvert->negative_sign : "-");
-#else
-	fpoint = 2;
-	dsymbol = '.';
-	ssymbol = ',';
-	csymbol = "$";
-	psymbol = '+';
-	nsymbol = "-";
-#endif
 
 #ifdef CASHDEBUG
 	printf("cashin- precision '%d'; decimal '%c'; thousands '%c'; currency '%s'; positive '%c'; negative '%s'\n",
@@ -206,7 +193,9 @@ cash_in(PG_FUNCTION_ARGS)
 		s++;
 
 	if (*s != '\0')
-		elog(ERROR, "Bad money external representation %s", str);
+		ereport(ERROR,
+				(errcode(ERRCODE_INVALID_TEXT_REPRESENTATION),
+				 errmsg("invalid input syntax for type money: \"%s\"", str)));
 
 	result = (value * sgn);
 
@@ -241,11 +230,8 @@ cash_out(PG_FUNCTION_ARGS)
 			   *nsymbol;
 	char		convention;
 
-#ifdef USE_LOCALE
 	struct lconv *lconvert = PGLC_localeconv();
-#endif
 
-#ifdef USE_LOCALE
 	/* see comments about frac_digits in cash_in() */
 	points = lconvert->frac_digits;
 	if (points < 0 || points > 10)
@@ -264,15 +250,6 @@ cash_out(PG_FUNCTION_ARGS)
 	dsymbol = ((*lconvert->mon_decimal_point != '\0') ? *lconvert->mon_decimal_point : '.');
 	csymbol = ((*lconvert->currency_symbol != '\0') ? lconvert->currency_symbol : "$");
 	nsymbol = ((*lconvert->negative_sign != '\0') ? lconvert->negative_sign : "-");
-#else
-	points = 2;
-	mon_group = 3;
-	comma = ',';
-	convention = 0;
-	dsymbol = '.';
-	csymbol = "$";
-	nsymbol = "-";
-#endif
 
 	point_pos = LAST_DIGIT - points;
 
@@ -315,7 +292,9 @@ cash_out(PG_FUNCTION_ARGS)
 	if (minus)
 	{
 		if (!PointerIsValid(result = palloc(CASH_BUFSZ + 2 - count + strlen(nsymbol))))
-			elog(ERROR, "Memory allocation failed, can't output cash");
+			ereport(ERROR,
+					(errcode(ERRCODE_OUT_OF_MEMORY),
+					 errmsg("out of memory")));
 
 		/* Position code of 0 means use parens */
 		if (convention == 0)
@@ -328,7 +307,9 @@ cash_out(PG_FUNCTION_ARGS)
 	else
 	{
 		if (!PointerIsValid(result = palloc(CASH_BUFSZ + 2 - count)))
-			elog(ERROR, "Memory allocation failed, can't output cash");
+			ereport(ERROR,
+					(errcode(ERRCODE_OUT_OF_MEMORY),
+					 errmsg("out of memory")));
 
 		strcpy(result, buf + count);
 	}
@@ -336,6 +317,34 @@ cash_out(PG_FUNCTION_ARGS)
 	PG_RETURN_CSTRING(result);
 }
 
+/*
+ *		cash_recv			- converts external binary format to cash
+ */
+Datum
+cash_recv(PG_FUNCTION_ARGS)
+{
+	StringInfo	buf = (StringInfo) PG_GETARG_POINTER(0);
+
+	PG_RETURN_CASH((Cash) pq_getmsgint(buf, sizeof(Cash)));
+}
+
+/*
+ *		cash_send			- converts cash to binary format
+ */
+Datum
+cash_send(PG_FUNCTION_ARGS)
+{
+	Cash		arg1 = PG_GETARG_CASH(0);
+	StringInfoData buf;
+
+	pq_begintypsend(&buf);
+	pq_sendint(&buf, arg1, sizeof(Cash));
+	PG_RETURN_BYTEA_P(pq_endtypsend(&buf));
+}
+
+/*
+ * Comparison functions
+ */
 
 Datum
 cash_eq(PG_FUNCTION_ARGS)
@@ -391,6 +400,20 @@ cash_ge(PG_FUNCTION_ARGS)
 	PG_RETURN_BOOL(c1 >= c2);
 }
 
+Datum
+cash_cmp(PG_FUNCTION_ARGS)
+{
+	Cash		c1 = PG_GETARG_CASH(0);
+	Cash		c2 = PG_GETARG_CASH(1);
+
+	if (c1 > c2)
+		PG_RETURN_INT32(1);
+	else if (c1 == c2)
+		PG_RETURN_INT32(0);
+	else
+		PG_RETURN_INT32(-1);
+}
+
 
 /* cash_pl()
  * Add two cash values.
@@ -468,7 +491,9 @@ cash_div_flt8(PG_FUNCTION_ARGS)
 	Cash		result;
 
 	if (f == 0.0)
-		elog(ERROR, "cash_div:  divide by 0.0 error");
+		ereport(ERROR,
+				(errcode(ERRCODE_DIVISION_BY_ZERO),
+				 errmsg("division by zero")));
 
 	result = rint(c / f);
 	PG_RETURN_CASH(result);
@@ -518,7 +543,9 @@ cash_div_flt4(PG_FUNCTION_ARGS)
 	Cash		result;
 
 	if (f == 0.0)
-		elog(ERROR, "cash_div:  divide by 0.0 error");
+		ereport(ERROR,
+				(errcode(ERRCODE_DIVISION_BY_ZERO),
+				 errmsg("division by zero")));
 
 	result = rint(c / f);
 	PG_RETURN_CASH(result);
@@ -569,7 +596,9 @@ cash_div_int4(PG_FUNCTION_ARGS)
 	Cash		result;
 
 	if (i == 0)
-		elog(ERROR, "cash_div_int4: divide by 0 error");
+		ereport(ERROR,
+				(errcode(ERRCODE_DIVISION_BY_ZERO),
+				 errmsg("division by zero")));
 
 	result = rint(c / i);
 
@@ -619,7 +648,9 @@ cash_div_int2(PG_FUNCTION_ARGS)
 	Cash		result;
 
 	if (s == 0)
-		elog(ERROR, "cash_div:  divide by 0 error");
+		ereport(ERROR,
+				(errcode(ERRCODE_DIVISION_BY_ZERO),
+				 errmsg("division by zero")));
 
 	result = rint(c / s);
 	PG_RETURN_CASH(result);
@@ -665,7 +696,7 @@ cash_words(PG_FUNCTION_ARGS)
 {
 	Cash		value = PG_GETARG_CASH(0);
 	unsigned int val;
-	char		buf[128];
+	char		buf[256];
 	char	   *p = buf;
 	Cash		m0;
 	Cash		m1;
@@ -688,8 +719,8 @@ cash_words(PG_FUNCTION_ARGS)
 
 	m0 = val % 100;				/* cents */
 	m1 = (val / 100) % 1000;	/* hundreds */
-	m2 = (val / 100000) % 1000;	/* thousands */
-	m3 = val / 100000000 % 1000; /* millions */
+	m2 = (val / 100000) % 1000; /* thousands */
+	m3 = val / 100000000 % 1000;	/* millions */
 
 	if (m3)
 	{
