@@ -3,26 +3,22 @@
  * cluster.h
  *	  header file for postgres cluster command stuff
  *
- * Portions Copyright (c) 1996-2001, PostgreSQL Global Development Group
+ * Portions Copyright (c) 1996-2003, PostgreSQL Global Development Group
  * Portions Copyright (c) 1994-5, Regents of the University of California
  *
- * $Id: cluster.h,v 1.9 2001/01/24 19:43:23 momjian Exp $
+ * $Id: cluster.h,v 1.19 2003/08/04 02:40:13 momjian Exp $
  *
  *-------------------------------------------------------------------------
  */
 #ifndef CLUSTER_H
 #define CLUSTER_H
 
-/*
- * defines for contant stuff
- */
-#define _TEMP_RELATION_KEY_				"clXXXXXXXX"
-#define _SIZE_OF_TEMP_RELATION_KEY_		11
+#include "nodes/parsenodes.h"
+#include "utils/rel.h"
 
 
-/*
- * functions
- */
-extern void cluster(char *oldrelname, char *oldindexname);
+extern void cluster(ClusterStmt *stmt);
 
-#endif	 /* CLUSTER_H */
+extern void rebuild_relation(Relation OldHeap, Oid indexOid);
+
+#endif   /* CLUSTER_H */
